package org.openxma.dsl.platform.config;

import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
import org.springframework.web.context.support.XmlWebApplicationContext;

/**
 * The default
 * {@link org.springframework.web.context.support.XmlWebApplicationContext}
 * configured with the <code>ConfigurableBeanDefinitionDocumentReader</code> as
 * bean definition reader.
 *
 * Capable of reading XProperties properties, therefore offering also a
 * solution</br> for establishing environment-specific spring context
 * configurations.
 *
 * If one would like to enable this class as the running spring application
 * context</br> within a web-application the web.xml has to be amended by the
 * following: "contextClass" context-param for ContextLoader or "contextClass"
 * init-param for FrameworkServlet.
 */
public class XPropertiesAwareXmlWebApplicationContext extends XmlWebApplicationContext {
    @Override
    protected void initBeanDefinitionReader(XmlBeanDefinitionReader beanDefinitionReader) {
        super.initBeanDefinitionReader(beanDefinitionReader);
        beanDefinitionReader.setDocumentReaderClass(ConfigurableBeanDefinitionDocumentReader.class);
    }
}
